package SAS::error;

require 5.005;

use Env;
use Carp;

use strict;
use vars qw($VERSION @ISA @EXPORT_OK %EXPORT_TAGS
	    $UIMsg $MetaMsg $AppMsg $AppLibMsg $LibMsg $CoreMsg $KernelMsg
	    $SilentMsg $SparseMsg $VerboseMsg $NoisyMsg);

require Exporter;

@ISA = qw(Exporter);

@EXPORT_OK = qw (message warning error fatal
		 UIMsg MetaMsg AppMsg AppLibMsg LibMsg CoreMsg KernelMsg
		 SilentMsg SparseMsg VerboseMsg NoisyMsg);

%EXPORT_TAGS = (functions => [qw(message warning error fatal)],
		msg_layers => [qw(UIMsg MetaMsg AppMsg AppLibMsg LibMsg CoreMsg KernelMsg)],
		msg_levels => [qw(SilentMsg SparseMsg VerboseMsg NoisyMsg)],
		);
		

# This line must not be broken (development)
$VERSION = do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf "%d."."%02d"x$#r,@r }; 

use errorc;

$UIMsg = $errorc::UIMsg;
$MetaMsg = $errorc::MetaMsg;
$AppMsg = $errorc::AppMsg;
$AppLibMsg = $errorc::AppLibMsg;
$LibMsg = $errorc::LibMsg;
$CoreMsg = $errorc::CoreMsg;
$KernelMsg = $errorc::KernelMsg;
$SilentMsg = $errorc::SilentMsg;
$SparseMsg = $errorc::SparseMsg;
$VerboseMsg = $errorc::VerboseMsg;
$NoisyMsg = $errorc::NoisyMsg;

sub message {
    my ($msgLayer, $msgLevel, $msg) = @_;
    &errorc::sas_string_message($msgLayer, $msgLevel, $msg);
}

sub warning {
    my ($code, $msg) = @_;
    &errorc::sas_string_warning($code, $msg);
}

sub error {
    my ($code, $msg) = @_;
    &errorc::sas_string_error($code, $msg);
}

sub fatal {
    my ($code, $msg) = @_;
    &errorc::sas_string_fatal($code, $msg);
}

1;

__END__


=head1 NAME

SAS::error - provide access to the SAS parameter interface

=head1 SYNOPSIS

    use SAS::error;

    SAS::error::message($msgLayer, $msgLevel, $msg);
    SAS::error::error($code, $msg);
    SAS::error::warning($code, $msg);
    SAS::error::fatal($code, $msg);

=head1 DESCRIPTION

C<SAS::error> provides access to the SAS error library. In the
following it is assumed that the reader understands the SAS error
library.

This module should be accessed through the C<SAS> modules, where the
function names are shorter. You should also look there for the documentation.

=head1 SEE ALSO

The following perl modules: DAL, SAS, SAS::param.

The SAS documentation.

=head1 AUTHOR

 Giuseppe Vacanti

=cut
