package SAS::param;

require 5.005;

use Env;
use Carp;

use strict;
use vars qw($VERSION @ISA @EXPORT);

require Exporter;

@ISA = qw(Exporter);

@EXPORT = qw (parameterCount intParameter realParameter
	      stringParameter booleanParameter);

# This line must not be broken (development)
$VERSION = do { my @r=(q$Revision: 1.5 $=~/\d+/g); sprintf "%d."."%02d"x$#r,@r }; 

use paramc;

sub parameterCount {
    my $name = shift;
    return &paramc::parameter_count($name);
}

sub intParameter {
    my ($name, $pos) = @_;
    $pos = -1 unless defined $pos;
    return &paramc::int_parameter($name, $pos);
}

sub realParameter {
    my ($name, $pos) = @_;
    $pos = -1 unless defined $pos;
    return &paramc::real_parameter($name, $pos);
}

sub stringParameter {
    my ($name, $pos) = @_;
    $pos = -1 unless defined $pos;
    return &paramc::string_parameter($name, $pos);
}

sub booleanParameter {
    my ($name, $pos) = @_;
    $pos = -1 unless defined $pos;
    return &paramc::boolean_parameter($name, $pos);
}


sub openParameters {
    my $name = shift;
    &paramc::open_parameters($name);
}

sub closeParameters {
    &paramc::close_parameters();
}

1;

__END__


=head1 NAME

SAS::param - provide access to the SAS parameter interface

=head1 SYNOPSIS

    use SAS::param;

=head1 DESCRIPTION

C<SAS::param> provides access to the SAS parameter interface. In the
following it is assumed that the reader understans the SAS parameter library.

The following functions are available:

=over 4

=item $count = parameterCount($param_name)

This returns the number of items in a list parameter.

=item $value = intParameter($param_name[, $position]);

This returns the value of of an integer parameter. If it is a list
parameter, it returns the value at $position in the list.

=item $value = realParameter($param_name[, $position]);

The same as above, but for real parameters.

=item $value = stringParameter($param_name[, $position]);

The same as above, but for string parameters.

=item $value = booleanParameter($param_name[, $position]);

The same as above, but for boolean parameters.

=head1 SEE ALSO

The following perl modules: DAL, SAS, SAS::error.

The SAS documentation.

=head1 AUTHOR

 Giuseppe Vacanti

=cut
