#! /usr/local/bin/perl
#

use Env;
use ExtUtils::MakeMaker;
use FileHandle;

WriteMakefile(
	      'NAME'    => 'errorc',
              'OBJECT' => 'errorc_wrap.o',
	      'CONFIGURE' => \&initialize,
	      'LD' => '$(CC) -shared',
	      );

sub initialize {
    my $self = {};

    my $lib;
    my $inc;

    foreach (split(":",$ENV{SAS_PATH})) {
	next if /^\s*$/;
	$inc .= " -I$_/include -I$_/include/error";
	$lib .= " -L$_/lib";
    }
    $lib.=" -lerror -lutils";
    $lib.=" ".find_egcs_library('stdc++');

    $self->{'INC'} =  $inc;
    $self->{'LIBS'}= $lib;

    return $self;
}

# -- these to be moved somewhere else

# find a header file in C_INCLUDE_PATH or CPLUS_INCLUDE_PATH
# return -I$dir 
sub find_header {
    my $header = shift;
    my @c_include_path = split /:/, $C_INCLUDE_PATH;
    my @cplus_include_path = split /:/, $CPLUS_INCLUDE_PATH;
    foreach my $dir (@c_include_path)
    {
	if(-e "$dir/$header")
	{
	    return "-I$dir";
	}
    }
    foreach my $dir (@cplus_include_path)
    {
	if(-e "$dir/$header")
	{
	    return "-I$dir";
	}
    }
    die("$header not found.\n");
}



# find a library in LD_LIBRARY_PATH or LIBRARY_PATH
# return -L$dir -l$lib
sub find_library {    
    my $lib = shift;
    my @ld_library_path = split /:/, $LD_LIBRARY_PATH;
    my @library_path = split /:/, $LIBRARY_PATH;
    foreach my $dir (@ld_library_path)
    {
	if(-e "$dir/lib$lib.so" or -e "$dir/lib$lib.a")
	{
	    return "-L$dir -l$lib";
	}
    }
    foreach my $dir (@library_path)
    {
	if(-e "$dir/lib$lib.a" or -e "$dir/lib$lib.so")
	{
	    return "-L$dir -l$lib";
	}
    }
    die("$lib not found.\n");
}

# find g++ library
# return -L$dir -l$lib
sub find_egcs_library {
    my $lib = shift;
    my $liba = `g++ -print-file-name=lib$lib.a`;
    my $libso = `g++ -print-file-name=lib$lib.so`;
    chomp($liba);
    chomp($libso);
    if(-e $liba)
    {
	my $l = quotemeta($lib);
	$liba =~ m{(/.+/)lib$l\.a};
	return "-L$1 -l$lib";
    } elsif(-e $libso)
    {
	my $l = quotemeta($lib);
	$libso =~ m{(/.+/)lib$l\.so};
	return "-L$1 -l$lib";
    } else {
	die "$lib not found.\n";
    }
}


